git_rev_parse

Function git_rev_parse 

pub fn git_rev_parse(args: &[&str]) -> Option<PathBuf>
Run git rev-parse with the given arguments and return the output as a path.

Returns None if git is not available, the command fails, or the output is empty.