pub fn git_rev_parse(args: &[&str]) -> Option<PathBuf>
Run git rev-parse with the given arguments and return the output as a path.
git rev-parse
Returns None if git is not available, the command fails, or the output is empty.
None